var React = require('react');
var formik = require('formik');
var FormGroup = require('reactstrap/lib/FormGroup');
var Label = require('reactstrap/lib/Label');
var Col = require('reactstrap/lib/Col');
var FormFeedback = require('reactstrap/lib/FormFeedback');
var NumberFormat = require('react-number-format');
var Input = require('reactstrap/lib/Input');
var DatePicker = require('react-datepicker');
var jsxRuntime = require('react/jsx-runtime');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return n;
}

var React__namespace = /*#__PURE__*/_interopNamespace(React);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var FormGroup__default = /*#__PURE__*/_interopDefaultLegacy(FormGroup);
var Label__default = /*#__PURE__*/_interopDefaultLegacy(Label);
var Col__default = /*#__PURE__*/_interopDefaultLegacy(Col);
var FormFeedback__default = /*#__PURE__*/_interopDefaultLegacy(FormFeedback);
var NumberFormat__default = /*#__PURE__*/_interopDefaultLegacy(NumberFormat);
var Input__default = /*#__PURE__*/_interopDefaultLegacy(Input);
var DatePicker__default = /*#__PURE__*/_interopDefaultLegacy(DatePicker);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function InputFieldInternal(props) {
  var placeholder = props.placeholder,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? undefined : _props$disabled,
      autoComplete = props.autoComplete,
      multiple = props.multiple,
      innerRef = props.innerRef,
      valid = props.valid,
      invalid = props.invalid,
      stringName = props.stringName,
      field = props.field,
      id = props.id,
      _onBlur = props.onBlur,
      initialVal = props.initialVal,
      type = props.type,
      numberFormatConfig = props.numberFormatConfig,
      parseValueAs = props.parseValueAs,
      setFieldValue = props.setFieldValue,
      _onChange = props.onChange,
      children = props.children,
      datePickerConfig = props.datePickerConfig;

  var commonInputProps = _extends({}, field, {
    name: stringName,
    valid: valid,
    invalid: invalid,
    id: id != null ? id : stringName,
    innerRef: innerRef,
    disabled: disabled,
    placeholder: placeholder,
    autoComplete: autoComplete,
    multiple: multiple,
    onBlur: function onBlur(e) {
      if (_onBlur) _onBlur(e);
    },
    defaultChecked: type === "checkbox" ? initialVal : undefined
  });

  var extendedType = numberFormatConfig ? "number-with-format" : type;

  switch (extendedType) {
    default:
      return /*#__PURE__*/jsxRuntime.jsx(Input__default["default"], _extends({}, commonInputProps, {
        type: type,
        onChange: function onChange(e) {
          switch (parseValueAs) {
            default:
              setFieldValue(field.name, parseValueAs(e.target.value));
              break;

            case "boolean":
              setFieldValue(field.name, !!e.target.value);
              break;

            case "string":
              field.onChange(e);
              break;

            case "number":
              if (type === "select" && multiple) {
                setFieldValue(field.name, Array.from(e.target.selectedOptions, function (option) {
                  return +option.value;
                }));
              } else {
                setFieldValue(field.name, +e.target.value);
              }

              break;
          }

          if (_onChange) {
            _onChange(e);
          }
        },
        children: children
      }));

    case "date":
      return /*#__PURE__*/jsxRuntime.jsx(jsxRuntime.Fragment, {
        children: /*#__PURE__*/jsxRuntime.jsx(DatePicker__default["default"], _extends({}, commonInputProps, {
          selected: field.value,
          dateFormat: "dd.MM.yyyy"
        }, datePickerConfig, {
          onChange: function onChange(date) {
            return setFieldValue(field.name, date);
          }
        }))
      });

    case "number-with-format":
      return /*#__PURE__*/jsxRuntime.jsx(NumberFormat__default["default"], _extends({}, commonInputProps, numberFormatConfig, {
        onValueChange: function onValueChange(values, sourceInfo) {
          setFieldValue(field.name, values.floatValue);

          if (_onChange) {
            _onChange(sourceInfo.event);
          }
        },
        onChange: function onChange() {// left intionally blank. We need to override it to make sure the built in
          // onChange coming from {...field} isn't fired.
        },
        customInput: Input__default["default"]
      }));
  }
}

function InputField(props) {
  var name = props.name,
      _props$type = props.type,
      type = _props$type === void 0 ? "text" : _props$type,
      _props$label = props.label,
      label = _props$label === void 0 ? name : _props$label,
      id = props.id,
      validation = props.validation,
      _props$parseValueAs = props.parseValueAs,
      parseValueAs = _props$parseValueAs === void 0 ? "string" : _props$parseValueAs,
      numberFormatConfig = props.numberFormatConfig,
      _props$fieldOnly = props.fieldOnly,
      fieldOnly = _props$fieldOnly === void 0 ? false : _props$fieldOnly;
  var pathArr = name.replace(/"/g, "").replace(/\[/g, ".").replace(/\]/g, "").split(".");
  var stringName = pathArr.join(".");

  var _useFormikContext = formik.useFormikContext(),
      setFieldValue = _useFormikContext.setFieldValue,
      initialValues = _useFormikContext.initialValues;

  var _useField = formik.useField({
    name: stringName,
    validate: validation
  }),
      field = _useField[0],
      meta = _useField[1];

  var valid = meta.touched && !meta.error;
  var invalid = meta.touched && !!meta.error;
  var initialVal = pathArr.reduce(function (obj, key) {
    return obj && obj[key] !== "undefined" ? obj[key] : undefined;
  }, initialValues);

  if (type === "checkbox" && typeof initialVal !== "boolean") {
    throw Error("Please supply a boolean initial Value for a checkbox. Field: \"" + stringName + "\", Value:\"" + initialVal + "\"");
  }

  if (numberFormatConfig && !["text", "tel", "password"].includes(type)) {
    throw Error("Number Format config only works together with input type text, tel or passowrd. Field: \"" + stringName + "\"");
  }

  var input = /*#__PURE__*/jsxRuntime.jsx(InputFieldInternal, _extends({}, props, {
    field: field,
    valid: valid,
    invalid: invalid,
    stringName: stringName,
    initialVal: initialVal,
    setFieldValue: setFieldValue,
    parseValueAs: parseValueAs
  }));

  return /*#__PURE__*/jsxRuntime.jsx(React__namespace.Fragment, {
    children: fieldOnly ? /*#__PURE__*/jsxRuntime.jsx(React__namespace.Fragment, {
      children: input
    }) : /*#__PURE__*/jsxRuntime.jsxs(FormGroup__default["default"], {
      row: true,
      children: [/*#__PURE__*/jsxRuntime.jsx(Label__default["default"], {
        "for": id != null ? id : stringName,
        sm: 6,
        children: label
      }), /*#__PURE__*/jsxRuntime.jsx(Col__default["default"], {
        sm: 6,
        children: input
      }), /*#__PURE__*/jsxRuntime.jsx(Col__default["default"], {
        sm: {
          size: 6,
          offset: 6
        },
        children: meta.touched && meta.error && /*#__PURE__*/jsxRuntime.jsx(FormFeedback__default["default"], {
          children: meta.error
        })
      })]
    })
  });
}

var Translations = /*#__PURE__*/function () {
  function Translations() {}

  Translations.getTranslations = function getTranslations() {
    return Translations.translations;
  };

  Translations.setTranslations = function setTranslations(translations) {
    Translations.translations = translations;
  };

  return Translations;
}();

Translations.translations = {
  passwordFieldTranslations: {
    errorRequired: "Input is mandatory",
    errorPasswordComplexity: "Password lenght must be between 8 and 40 characters",
    errorPasswordComplexityCharacters: "The password must contain at least 1 uppercase, 1 lowercase character and 1 digit.",
    errorPasswordsAreNotIdentical: "The passwords are not identical"
  }
};

var PasswordField = function PasswordField(_ref) {
  var name = _ref.name,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? name : _ref$label,
      confirmFieldName = _ref.confirmFieldName,
      _ref$confirmFieldLabe = _ref.confirmFieldLabel,
      confirmFieldLabel = _ref$confirmFieldLabe === void 0 ? confirmFieldName : _ref$confirmFieldLabe,
      _ref$checkPasswordCom = _ref.checkPasswordComplexity,
      checkPasswordComplexity = _ref$checkPasswordCom === void 0 ? true : _ref$checkPasswordCom,
      customTranslations = _ref.customTranslations;
  var regexp = new RegExp("((?=.*\\d)(?=.*[a-z])(?=.*[A-Z]).)");

  var _useFormikContext = formik.useFormikContext(),
      values = _useFormikContext.values;

  var translations = customTranslations || Translations.getTranslations().passwordFieldTranslations;
  return /*#__PURE__*/jsxRuntime.jsxs(React__default["default"].Fragment, {
    children: [/*#__PURE__*/jsxRuntime.jsx(InputField, {
      type: "password",
      name: name,
      label: label,
      autoComplete: confirmFieldName ? "new-password" : "current-password",
      validation: function validation(value) {
        if (!value) {
          return translations.errorRequired;
        }

        if (checkPasswordComplexity) {
          if (value.length < 8 || value.length > 40) {
            return translations.errorPasswordComplexity;
          }

          if (!regexp.test(value)) {
            return translations.errorPasswordComplexityCharacters;
          }
        }

        return undefined;
      }
    }), confirmFieldName && /*#__PURE__*/jsxRuntime.jsx(InputField, {
      type: "password",
      name: confirmFieldName,
      label: confirmFieldLabel,
      autoComplete: "new-password",
      validation: function validation(value) {
        if (!value) {
          return translations.errorRequired;
        }

        if (value !== values[name]) {
          return translations.errorPasswordsAreNotIdentical;
        }

        return undefined;
      }
    })]
  });
};

var _excluded = ["children", "initialValues", "onSubmit"];

function FormikWrapper(props) {
  var _children = props.children,
      initialValues = props.initialValues,
      _onSubmit = props.onSubmit,
      rest = _objectWithoutPropertiesLoose(props, _excluded);

  function isFunction(fn) {
    return fn && {}.toString.call(fn) === "[object Function]";
  }

  function cleanInitialValus(item) {
    Object.keys(item).forEach(function (key) {
      // eslint-disable-next-line no-param-reassign
      if (item[key] === undefined) item[key] = "";
    });
    return item;
  }

  function cleanSubmitValues(item) {
    Object.keys(item).forEach(function (key) {
      // eslint-disable-next-line no-param-reassign
      if (item[key] === "") delete item[key];
    });
    return item;
  } // const cleanedInitialValues =


  return /*#__PURE__*/jsxRuntime.jsx(React__namespace.Fragment, {
    children: /*#__PURE__*/jsxRuntime.jsx(formik.Formik, _extends({}, rest, {
      initialValues: cleanInitialValus(initialValues),
      onSubmit: function onSubmit(values, helpers) {
        _onSubmit(cleanSubmitValues(values), helpers);
      },
      children: function children(formProps) {
        return /*#__PURE__*/jsxRuntime.jsx(formik.Form, {
          children: isFunction(_children) ? _children(formProps) : _children
        });
      }
    }))
  });
}

exports.FormikWrapper = FormikWrapper;
exports.FormuUiTranslations = Translations;
exports.InputField = InputField;
exports.PasswordField = PasswordField;
//# sourceMappingURL=index.js.map
