import * as React from 'react';
import React__default from 'react';
import { useFormikContext, useField, Formik, Form } from 'formik';
import FormGroup from 'reactstrap/lib/FormGroup';
import Label from 'reactstrap/lib/Label';
import Col from 'reactstrap/lib/Col';
import FormFeedback from 'reactstrap/lib/FormFeedback';
import NumberFormat from 'react-number-format';
import Input from 'reactstrap/lib/Input';
import DatePicker from 'react-datepicker';
import { jsx, Fragment, jsxs } from 'react/jsx-runtime';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function InputFieldInternal(props) {
  const {
    placeholder,
    disabled = undefined,
    autoComplete,
    multiple,
    innerRef,
    valid,
    invalid,
    stringName,
    field,
    id,
    onBlur,
    initialVal,
    type,
    numberFormatConfig,
    parseValueAs,
    setFieldValue,
    onChange,
    children,
    datePickerConfig
  } = props;

  const commonInputProps = _extends({}, field, {
    name: stringName,
    valid,
    invalid,
    id: id != null ? id : stringName,
    innerRef,
    disabled,
    placeholder,
    autoComplete,
    multiple,
    onBlur: e => {
      if (onBlur) onBlur(e);
    },
    defaultChecked: type === "checkbox" ? initialVal : undefined
  });

  const extendedType = numberFormatConfig ? "number-with-format" : type;

  switch (extendedType) {
    default:
      return /*#__PURE__*/jsx(Input, _extends({}, commonInputProps, {
        type: type,
        onChange: e => {
          switch (parseValueAs) {
            default:
              setFieldValue(field.name, parseValueAs(e.target.value));
              break;

            case "boolean":
              setFieldValue(field.name, !!e.target.value);
              break;

            case "string":
              field.onChange(e);
              break;

            case "number":
              if (type === "select" && multiple) {
                setFieldValue(field.name, Array.from(e.target.selectedOptions, option => +option.value));
              } else {
                setFieldValue(field.name, +e.target.value);
              }

              break;
          }

          if (onChange) {
            onChange(e);
          }
        },
        children: children
      }));

    case "date":
      return /*#__PURE__*/jsx(Fragment, {
        children: /*#__PURE__*/jsx(DatePicker, _extends({}, commonInputProps, {
          selected: field.value,
          dateFormat: "dd.MM.yyyy"
        }, datePickerConfig, {
          onChange: date => setFieldValue(field.name, date)
        }))
      });

    case "number-with-format":
      return /*#__PURE__*/jsx(NumberFormat, _extends({}, commonInputProps, numberFormatConfig, {
        onValueChange: (values, sourceInfo) => {
          setFieldValue(field.name, values.floatValue);

          if (onChange) {
            onChange(sourceInfo.event);
          }
        },
        onChange: () => {// left intionally blank. We need to override it to make sure the built in
          // onChange coming from {...field} isn't fired.
        },
        customInput: Input
      }));
  }
}

function InputField(props) {
  const {
    name,
    type = "text",
    label = name,
    id,
    validation,
    parseValueAs = "string",
    numberFormatConfig,
    fieldOnly = false
  } = props;
  const pathArr = name.replace(/"/g, "").replace(/\[/g, ".").replace(/\]/g, "").split(".");
  const stringName = pathArr.join(".");
  const {
    setFieldValue,
    initialValues
  } = useFormikContext();
  const [field, meta] = useField({
    name: stringName,
    validate: validation
  });
  const valid = meta.touched && !meta.error;
  const invalid = meta.touched && !!meta.error;
  const initialVal = pathArr.reduce((obj, key) => obj && obj[key] !== "undefined" ? obj[key] : undefined, initialValues);

  if (type === "checkbox" && typeof initialVal !== "boolean") {
    throw Error(`Please supply a boolean initial Value for a checkbox. Field: "${stringName}", Value:"${initialVal}"`);
  }

  if (numberFormatConfig && !["text", "tel", "password"].includes(type)) {
    throw Error(`Number Format config only works together with input type text, tel or passowrd. Field: "${stringName}"`);
  }

  const input = /*#__PURE__*/jsx(InputFieldInternal, _extends({}, props, {
    field: field,
    valid: valid,
    invalid: invalid,
    stringName: stringName,
    initialVal: initialVal,
    setFieldValue: setFieldValue,
    parseValueAs: parseValueAs
  }));

  return /*#__PURE__*/jsx(React.Fragment, {
    children: fieldOnly ? /*#__PURE__*/jsx(React.Fragment, {
      children: input
    }) : /*#__PURE__*/jsxs(FormGroup, {
      row: true,
      children: [/*#__PURE__*/jsx(Label, {
        for: id != null ? id : stringName,
        sm: 6,
        children: label
      }), /*#__PURE__*/jsx(Col, {
        sm: 6,
        children: input
      }), /*#__PURE__*/jsx(Col, {
        sm: {
          size: 6,
          offset: 6
        },
        children: meta.touched && meta.error && /*#__PURE__*/jsx(FormFeedback, {
          children: meta.error
        })
      })]
    })
  });
}

class Translations {
  static getTranslations() {
    return Translations.translations;
  }

  static setTranslations(translations) {
    Translations.translations = translations;
  }

}

Translations.translations = {
  passwordFieldTranslations: {
    errorRequired: "Input is mandatory",
    errorPasswordComplexity: "Password lenght must be between 8 and 40 characters",
    errorPasswordComplexityCharacters: "The password must contain at least 1 uppercase, 1 lowercase character and 1 digit.",
    errorPasswordsAreNotIdentical: "The passwords are not identical"
  }
};

const PasswordField = ({
  name,
  label: _label = name,
  confirmFieldName,
  confirmFieldLabel: _confirmFieldLabel = confirmFieldName,
  checkPasswordComplexity: _checkPasswordComplexity = true,
  customTranslations
}) => {
  const regexp = new RegExp("((?=.*\\d)(?=.*[a-z])(?=.*[A-Z]).)");
  const {
    values
  } = useFormikContext();
  const translations = customTranslations || Translations.getTranslations().passwordFieldTranslations;
  return /*#__PURE__*/jsxs(React__default.Fragment, {
    children: [/*#__PURE__*/jsx(InputField, {
      type: "password",
      name: name,
      label: _label,
      autoComplete: confirmFieldName ? "new-password" : "current-password",
      validation: value => {
        if (!value) {
          return translations.errorRequired;
        }

        if (_checkPasswordComplexity) {
          if (value.length < 8 || value.length > 40) {
            return translations.errorPasswordComplexity;
          }

          if (!regexp.test(value)) {
            return translations.errorPasswordComplexityCharacters;
          }
        }

        return undefined;
      }
    }), confirmFieldName && /*#__PURE__*/jsx(InputField, {
      type: "password",
      name: confirmFieldName,
      label: _confirmFieldLabel,
      autoComplete: "new-password",
      validation: value => {
        if (!value) {
          return translations.errorRequired;
        }

        if (value !== values[name]) {
          return translations.errorPasswordsAreNotIdentical;
        }

        return undefined;
      }
    })]
  });
};

const _excluded = ["children", "initialValues", "onSubmit"];

function FormikWrapper(props) {
  const {
    children,
    initialValues,
    onSubmit
  } = props,
        rest = _objectWithoutPropertiesLoose(props, _excluded);

  function isFunction(fn) {
    return fn && {}.toString.call(fn) === "[object Function]";
  }

  function cleanInitialValus(item) {
    Object.keys(item).forEach(key => {
      // eslint-disable-next-line no-param-reassign
      if (item[key] === undefined) item[key] = "";
    });
    return item;
  }

  function cleanSubmitValues(item) {
    Object.keys(item).forEach(key => {
      // eslint-disable-next-line no-param-reassign
      if (item[key] === "") delete item[key];
    });
    return item;
  } // const cleanedInitialValues =


  return /*#__PURE__*/jsx(React.Fragment, {
    children: /*#__PURE__*/jsx(Formik, _extends({}, rest, {
      initialValues: cleanInitialValus(initialValues),
      onSubmit: (values, helpers) => {
        onSubmit(cleanSubmitValues(values), helpers);
      },
      children: formProps => /*#__PURE__*/jsx(Form, {
        children: isFunction(children) ? children(formProps) : children
      })
    }))
  });
}

export { FormikWrapper, Translations as FormuUiTranslations, InputField, PasswordField };
//# sourceMappingURL=index.modern.mjs.map
